# OPNV Dataset - Open public network for versatile data

![AmeiseLogo](https://raw.githubusercontent.com/MarcelVSHNS/ameise-dataset/main/docs/Ameise_logo.png) 

Dev-Kit for [Project AMEISE](https://ameise.wandelgesellschaft.de/) records: 

## Description

The OPNV-dataset is a development kit for the OPNV dataset. It provides functionalities to unpack AMEISE record 
files and extract meta information and frames. The core functionality revolves around handling AMEISE record files 
with the .4mse extension.

## Installation

To install the ameise-dataset, you can use pip:
```console
pip install ameise
```

## Getting Started

To get started with the dataset, you can refer to the [GettingStarted.ipynb](https://colab.research.google.com/drive/1p2cw3bSZ6B798qQ2jVnpvKQI5pv_-y_D?usp=sharing) notebook provided in the repository. 
This notebook will guide you through the basic functionalities and usage of the dataset.
